
$TITLE eps-Constraint Method for Multiobjective Optimization (EPSCM,SEQ=319)
$ontext
The eps-Constraint Method

This is a GAMS implementation of the augmented eps-constraint method
for generating the efficient (Pareto optimal, nondominated) solutions
in multiobjective problems. The eps-constraint method optimizes one of
the objective functions using the remaining objective functions as
constraints, varying their right hand side.

The generated optimal solutions proved to be efficient solutions of
the multiobjective problem under certain conditions.

The eps-constraint method consists of two phases:
1. Creation of the payoff table
2. Use the ranges from the payoff table in order to apply the method

The augmented eps-constraint uses lexicographic optimization in the
construction of the payoff table (in order to secure the Pareto
optimality of the individual optima) and a slightly modified objective
function in order to ensure the production of Pareto optimal (and not
weakly Pareto optimal) solutions. In addition, it performs early exit
from infeasible loops improving the performance of the algorithm in
multi-objective problems with several objective functions.

The algorithm can work also with MIP models. Actually the advantages
of the eps-constraint method over the weighting method are more
apparent for MIP problems where the non supported Pareto optimal
solutions can be produced.

A simplified power generation problem is used to illustrate the
method:

Four types of power generation units are considered in a region,
namely, lignite fired, oil fired, natural gas fired and units
exploiting renewable energy sources (RES) which are mostly small hydro
and wind.  The power generation characteristics of these units are
shown in table pdata.

The yearly demand is 64000 GWh and is characterized by a load duration
curve which can be divided into three type of loads: base load (60%),
medium load (30%) and peak load (10%). The lignite fired units can be
used only for base and middle load, the oil fired units for middle and
peak load, the RES units for base and peak load and the natural gas
fired units for all type of loads. The endogenous sources are lignite
and RES.

We consider three objective functions: the minimization of production
cost, the minimization of CO2 emissions and the minimization of
external dependence (i.e. oil and natural gas) by maximizing the
endogenous energy sources.  The task is to generate the payoff table
and the Pareto optimal (efficient, non-dominated) solutions of the
problem.

Additional information can be found at:

http://www.gams.com/modlib/adddocs/epscm.pdf


Mavrotas, G, Generation of efficient solutions in Multiobjective Mathematical
Programming problems using GAMS. Tech. rep., School of Chemical Engineering,
National Technical University of Athens, 2006.
$offtext

$inlinecom [ ]
$eolcom //
$STitle Example model definitions

*Define index sets
SETS     i component /EMIMBF4, BMIMCl, EMIMEtSO4, EMIMDMP, EG, glycerol,
                      H2O,sulfuric-acid, lime, NH3, NH4OH,  air, citric-acid,
                      NREL-enzyme, spezyme-enzyme, CSL, DAP, C6-frac, H2, O2,
                      glucan, xylan, acetate, arabinan, mannan, galactan,
                      lignin, glucose, glucose-oligomer,cellobiose, xylose,
                      xylose-oligomer, arabinose, mannose, galactose,
                      acetic-acid, furfural, soluble-lignin, CO2, C2H5OH,
                      succinic-acid, lactic-acid, HMF, Zmobilis, xylitol,
                      gypsum, inert, crude-oil, IBP62, gasoline,
                      remv-hydrofin, diesel, benzene, pentane, isopentane,
                      butane, isobutane, propane, dry-gas, sulfur,
                      boiler-fuel, losser, gasohol/

         react(i) reactans /sulfuric-acid,glucan,xylan,acetate,arabinan,
                            lignin,cellobiose,glucose,xylose,mannan,galactan,
                            arabinose,mannose,galactose, crude-oil/

         rr reactions /1*35/

         cas interval /1*33/
          k      objective functions /dechet, ethanol, invest, fonct/
         alias(cas,cascas)
         alias(i,ii)   ;
$set min -1
$set max +1
Parameter dir(k) direction of the objective functions
   /ethanol %max%, dechet %min%, invest %min%, fonct %min%/;
* interval 1 is feed box
* interval 2 is oil refinery
* interval 3 and 4 are in stage 1 [= size reduction]
* interval 5 to interval 9 are in stage 2 [= pretreatment process]
*  - interval 5 = AFEX process
*  - interval 6 = dilute acid process
*  - interval 7 = controlled-pH process
*  - interval 8 = APR process
*  - interval 9 = lime process
* interval 10 to interval 11 are in stage 3 [=hydrolysis]
*  - interval 10  = dilute acid hydrolysis (0.4% H2SO4+washing water)
*  - interval 11 = concentrate acid hydrolysis (50% H2SO4+washing water)
*  - interval 12 = enzyme data from NREL 2002 report
*  - interval 13 = spyzyme enzyme with the stream coming from AFEX pretreatment
*  - interval 14 = spyzyme enzyme with the stream coming from dilute acid pretreatment
*  - interval 15 = spyzyme enzyme with the stream coming from controlled-pH pretreatment
*  - interval 16 = spyzyme enzyme with the stream coming from APR pretreatment
*  - interval 17 = spyzyme enzyme with the stream coming from Lime pretreatment
*  - interval 18 = blank block to send the stream from interval 9 to interval 20
* interval 19 and 20 are in stage 4 [=seed production]
*  - interval 19 = 10% of stream is sent to this interval
*  - interval 20 = 90% of stream is sent to this interval (no reaction occur)
* interval 21 is in stage 5 [=fermentation process by z.mobilize]
* interval 22 to 32 are in stage 6 [=separation process]
*  - interval 22 = distillation 1 (5.4%ethanol pure)
*  - interval 23 = distillation 2 (89.55%ethanol pure)
*  - interval 24 = solvent extraction by EG  (99.84%ethanol pure)
*  - interval 25 = solvent extraction by glycerol (99.84%ethanol pure)
*  - interval 26 = ionic liquid extraction by EMIMBF4 (99.84%ethanol pure)
*  - interval 27 = ionic liquid extraction by BMIMCl (99.84%ethanol pure)
*  - interval 28 = ionic liquid extraction by EMIMEtSO4 (99.84%ethanol pure)
*  - interval 29 = ionic liquid extraction by EMIMDMP (99.84%ethanol pure)
*  - interval 30 = membrain separation (99.84%ethanol pure)
*  - interval 31 = adsorption (99.84%ethanol pure)
*  - interval 32 = 81% ethanol
*  - interval 32 = 99.9% ethanol

*reaction
*pretreatment reaction
*reaction 1:  (Glucan)n  +  nH2O  =  n Glucose
*reaction 2:  (Glucan)n  +  nH2O  =  m Glucose Oligomer
*reaction 3:  (Glucan)n  +   nH2O  =   n Cellobiose
*reaction 4:  (Xylan)n   +  nH2O  =  n Xylose
*reaction 5:  (Xylan)n   +  mH2O  =  m Xylose Oligomer
*reaction 6:  (Xylan)n            =  n Furfural + 2H2O
*reaction 7:  Acetate             =  Acetic acid
*reaction 8:  (Lignin)n           =  n Soluble lignin
*reaction 9:  arabinan + H2O      =  Arabinose
*reaction 10: H2SO4 + Lime        =  Gypsum
*hydrolysis reaction
*reaction 11: (Glucan)n           =  n Glucose Oligomer
*reaction 12: (Glucan)n  +   nH2O  =  n Cellobiose
*reaction 13: (Glucan)n  +  nH2O  =  n Glucose
*reaction 14: Cellobiose  +  H2O  =  2 Glucose
*reaction 15: (xylan)n            =  n xylan oligomer
*reaction 16: (xylan )n + nH2O    =  n xylose
*reaction 17: mannan + H2O = mannose
*reaction 18: galactan +H2O = galactose
*Seed train and fermentration reaction
*reaction 19: Glucose             =  2C2H5OH + 2CO2
*reaction 20: Glucose+CSL+0.018DAP = 6 Z. mobilis + 2.4H2O + 0.3O2
*reaction 21: Glucose   +   2 H2O =  2 Glycerol  +  O2
*reaction 22: Glucose   +   2 CO2 =  2 Succinic acid +  O2
*reaction 23: Glucose             =  3 Acetic acid
*reaction 24: Glucose             =  2 Lactic acid
*reaction 25: 3 Xylose            =  5 C2H5OH  +  5CO2
*reaction 26: Xylose+0.835+CSL+0.015DAP = 5 Z. mobilis + 2H2O + 0.25O2
*reaction 27: 3Xylose +  5 H2O    =  5 Glycerol  +  2.5O2
*reaction 28: Xylose  +  H2O      =  Xylitiol  +  9.5 O2   (for seed)
*reaction 28: Xylose  +  H2O      =  Xylitiol  +  2.5 O2   (for fermentation)
*reaction 29: 3Xylose +  5 CO2    =  5 Succinic acid + 2.5O2
*reaction 30: 2Xylose             =  5 Acetic acid
*reaction 31: 3Xylose             =  5 Lactic acid
*reaction 32: Mannose             = 2Ethanol + 2CO2
*reaction 33: Galactose           = 2Ethanol + 2CO2
*reaction 34: arabinose           = 5Ethanol + 5CO2
*reaction 35: crude-oil + 0.022C6 + 0.004H2 = 0.023IBP62 + 0.02gasoline + 0.007remove-hydrofin
*                                             + 0.266diesel + 0.008benzene + 0.017pentane + 0.02isopentane
*                                             + 0.02butane + 0.022isobutane + 0.025propane + 0.011dry-gas
*                                             + 0.003sulfur + 0.558boiler + 0.028losser


Parameter   MW(i) Molecular weight of component i
/EMIMBF4          197.97
 BMIMCl           174.67
 EMIMEtSO4        236.29
 EMIMDMP          236.21
 EG               62.068
 glycerol          92
 H2O               18.02
 sulfuric-acid     98
 lime              74
 NH3               17
 NH4OH             35
 air                0
 citric-acid        0
 NREL-enzyme        0
 spezyme-enzyme     0
 CSL                0
 DAP                0
 C6-frac            0
 H2                 2
 O2                32
 glucan           162.00
 xylan            132.00
 acetate           60.00
 arabinan         132.00
 mannan           162.00
 galactan         162.00
 lignin           154.70
 glucose          180.00
 glucose-oligomer 180.00
 cellobiose       342
 xylose           150
 xylose-oligomer  150
 arabinose        150
 mannose          180
 galactose        180
 acetic-acid       60
 furfural          96
 soluble-lignin   154.70
 CO2               44
 C2H5OH            46
 succinic-acid    118
 lactic-acid       90
 HMF               97
 Zmobilis           0
 xylitol          152
 gypsum           172.00
 inert              0
 crude-oil          0
 IBP62              0
 gasoline           0
 remv-hydrofin      0
 diesel             0
 benzene           78
 pentane           72
 isopentane        72
 butane            58
 isobutane         58
 propane           44
 dry-gas            0
 sulfur            64
 boiler-fuel        0
 losser             0
 gasohol            0   /

Parameter   PHI(i) Composition of the biomass feed
/ H2                     0
 O2                      0
 glucan                  36.1
 xylan                   21.4
 acetate                 3.2
 arabinan                3.6
 mannan                  0
 galactan                0
 lignin                  17.2
 glucose                 0
 glucose-oligomer        0
 cellobiose              0
 xylose                  0
 xylose-oligomer         0
 arabinose               0
 mannose                 0
 galactose               0
 acetic-acid             0
 furfural                0
 soluble-lignin          0
 CO2                     0
 C2H5OH                  0
 succinic-acid           0
 lactic-acid             0
 HMF                     0
 Zmobilis                0
 xylitol                 0
 inert                   21.1 /

Parameter   crude(i) composition of the crude oil feed
/ crude-oil               100 /


Scalar      M /100000000/;

Table       SS(cas,cascas) matching the interval with another interval
     1  2  3  4  5  6  7  8  9  10 11 12 13 14 15 16 17 18 19  20  21 22 23 24 25 26 27 28 29 30 31 32 33
1    0  1  1  1  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0   0   0  0  0  0  0  0  0  0  0  0  0  0  0
2    0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0   0   0  0  0  0  0  0  0  0  0  0  0  0  0
3    0  0  0  0  1  0  0  0  0  0  0  0  0  0  0  0  0  0  0   0   0  0  0  0  0  0  0  0  0  0  0  0  0
4    0  0  0  0  0  1  1  1  1  0  0  0  0  0  0  0  0  0  0   0   0  0  0  0  0  0  0  0  0  0  0  0  0
5    0  0  0  0  0  0  0  0  0  0  0  1  1  0  0  0  0  0  0   0   0  0  0  0  0  0  0  0  0  0  0  0  0
6    0  0  0  0  0  0  0  0  0  1  1  1  0  1  0  0  0  0  0   0   0  0  0  0  0  0  0  0  0  0  0  0  0
7    0  0  0  0  0  0  0  0  0  0  0  1  0  0  1  0  0  0  0   0   0  0  0  0  0  0  0  0  0  0  0  0  0
8    0  0  0  0  0  0  0  0  0  0  0  1  0  0  0  1  0  0  0   0   0  0  0  0  0  0  0  0  0  0  0  0  0
9    0  0  0  0  0  0  0  0  0  0  0  1  0  0  0  0  1  1  0   0   0  0  0  0  0  0  0  0  0  0  0  0  0
10   0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0.1 0.9 0  0  0  0  0  0  0  0  0  0  0  0  0
11   0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0.1 0.9 0  0  0  0  0  0  0  0  0  0  0  0  0
12   0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0.1 0.9 0  0  0  0  0  0  0  0  0  0  0  0  0
13   0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0.1 0.9 0  0  0  0  0  0  0  0  0  0  0  0  0
14   0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0.1 0.9 0  0  0  0  0  0  0  0  0  0  0  0  0
15   0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0.1 0.9 0  0  0  0  0  0  0  0  0  0  0  0  0
16   0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0.1 0.9 0  0  0  0  0  0  0  0  0  0  0  0  0
17   0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0.1 0.9 0  0  0  0  0  0  0  0  0  0  0  0  0
18   0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0   1   0  0  0  0  0  0  0  0  0  0  0  0  0
19   0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0   0   1  0  0  0  0  0  0  0  0  0  0  0  0
20   0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0   0   1  0  0  0  0  0  0  0  0  0  0  0  0
21   0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0   0   0  1  0  0  0  0  0  0  0  0  0  0  0
22   0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0   0   0  0  1  0  0  0  0  0  0  0  0  0  0
23   0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0   0   0  0  0  1  1  1  1  1  1  1  1  0  0
24   0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0   0   0  0  0  0  0  0  0  0  0  0  0  0  1
25   0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0   0   0  0  0  0  0  0  0  0  0  0  0  0  1
26   0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0   0   0  0  0  0  0  0  0  0  0  0  0  0  1
27   0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0   0   0  0  0  0  0  0  0  0  0  0  0  0  1
28   0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0   0   0  0  0  0  0  0  0  0  0  0  0  0  1
29   0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0   0   0  0  0  0  0  0  0  0  0  0  0  0  1
30   0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0   0   0  0  0  0  0  0  0  0  0  0  0  0  1
31   0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0   0   0  0  0  0  0  0  0  0  0  0  0  0  1
32   0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0   0   0  0  0  0  0  0  0  0  0  0  0  0  0
33   0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0   0   0  0  0  0  0  0  0  0  0  0  0  0  0 ;

Table       epsilon(i,cas,cascas) split factor of product going into the interval
                             1 2 3   4   5   6   7   8   9   10  11   12  13   14   15   16   17   18   19   20   21   22   23   24   25   26   27   28   29   30   31   32   33
EMIMBF4.(1*33)               0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
BMIMCl.(1*33)                0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
EMIMEtSO4.(1*33)             0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
EMIMDMP.(1*33)               0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
EG.(1*33)                    0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
H2O.(1*33)                   0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
sulfuric-acid.(1*33)         0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
lime.(1*33)                  0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
NH3.(1*33)                   0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
NH4OH.(1*33)                 0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
air.(1*33)                   0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
O2.(1*33)                    0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
citric-acid.(1*33)           0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
NREL-enzyme.(1*33)           0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
spezyme-enzyme.(1*33)        0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
CSL.(1*33)                   0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
DAP.(1*33)                   0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
glucan.(1*33)                0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
xylan.(1*33)                 0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
acetate.(1*33)               0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
arabinan.(1*33)              0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
mannan.(1*33)                0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
galactan.(1*33)              0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
lignin.(1*33)                0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
glucose.(1*8,10*33)          0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
glucose.(9)                  0 0 1   1   1   1   1   1   1   1   1    0   1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
glucose-oligomer.(1*8,10*33) 0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
glucose-oligomer.(9)         0 0 1   1   1   1   1   1   1   1   1    0   1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
cellobiose.(1*33)            0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
xylose.(1*8,10*33)           0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
xylose.(9)                   0 0 1   1   1   1   1   1   1   1   1    0   1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
xylose-oligomer.(1*8,10*33)  0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
xylose-oligomer.(9)          0 0 1   1   1   1   1   1   1   1   1    0   1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
arabinose.(1*33)             0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
mannose.(1*33)               0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
galactose.(1*33)             0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
acetic-acid.(1*33)           0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
furfural.(1*33)              0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
soluble-lignin.(1*33)        0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
CO2.(1*33)                   0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
C2H5OH.(1*33)                0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
glycerol.(1*33)              0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
succinic-acid.(1*33)         0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
lactic-acid.(1*33)           0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
HMF.(1*33)                   0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
Zmobilis.(1*33)              0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
xylitol.(1*33)               0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
gypsum.(1*33)                0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
inert.(1*33)                 0 0 1   1   1   1   1   1   1   1   1    1   1    1    1    1    1    0    1    1    1    1    1    1    1    1    1    1    1    1    1    1    1
crude-oil.(1*33)             0 1 0   0   0   0   0   0   0   0   0    0   0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0
C6-frac.(1*33)               0 1 0   0   0   0   0   0   0   0   0    0   0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0
H2.(1*33)                    0 1 0   0   0   0   0   0   0   0   0    0   0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0
IBP62.(1*33)                 0 1 0   0   0   0   0   0   0   0   0    0   0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0
gasoline.(1*33)              0 1 0   0   0   0   0   0   0   0   0    0   0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0
remv-hydrofin.(1*33)         0 1 0   0   0   0   0   0   0   0   0    0   0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0
diesel.(1*33)                0 1 0   0   0   0   0   0   0   0   0    0   0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0
benzene.(1*33)               0 1 0   0   0   0   0   0   0   0   0    0   0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0
pentane.(1*33)               0 1 0   0   0   0   0   0   0   0   0    0   0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0
isopentane.(1*33)            0 1 0   0   0   0   0   0   0   0   0    0   0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0
butane.(1*33)                0 1 0   0   0   0   0   0   0   0   0    0   0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0
isobutane.(1*33)             0 1 0   0   0   0   0   0   0   0   0    0   0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0
propane.(1*33)               0 1 0   0   0   0   0   0   0   0   0    0   0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0
dry-gas.(1*33)               0 1 0   0   0   0   0   0   0   0   0    0   0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0
sulfur.(1*33)                0 1 0   0   0   0   0   0   0   0   0    0   0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0
boiler-fuel.(1*33)           0 1 0   0   0   0   0   0   0   0   0    0   0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0
losser.(1*33)                0 1 0   0   0   0   0   0   0   0   0    0   0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0    0  ;

Table        SW(i,cascas) waste fraction
                                 1    2    3    4   5   6      7   8      9      10   11   12  13  14   15   16   17   18   19   20   21   22       23       24       25       26       27        28       29        30       31       32   33
             EMIMBF4             0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        0        0        0        1        0         0        0         0        0        0    0
             BMIMCl              0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        0        0        0        0        1         0        0         0        0        0    0
             EMIMEtSO4           0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        0        0        0        0        0         1        0         0        0        0    0
             EMIMDMP             0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        0        0        0        0        0         0        1         0        0        0    0
             EG                  0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        0        0.9618   0        0        0         0        0         0        0        0    0
             H2O                 0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0.0009   0.99249  0.99805  0.99805  1        1         1        1         0.99805  0.99805  0    0
             sulfuric-acid       0    0    0    0   0   1      0   0      0      1    1    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             lime                0    0    0    0   0   1      0   0      1      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             NH3                 0    0    0    0   1   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    1        0.00064  0        0        0        0         0        0         0        0        0    0
             NH4OH               0    0    0    0   0   0      0   1      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             air                 0    0    0    0   0   1      0   0      1      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             O2                  0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    1    0    0    1        1        0        0        0        0         0        0         0        0        0    0
             citric-acid         0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             NREL-enzyme         0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             spezyme-enzyme      0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             CSL                 0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0.000866 1        0        0        0        0         0        0         0        0        0    0
             DAP                 0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             glucan              0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             xylan               0    0    0    0   0   0      0   0.0892 0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             acetate             0    0    0    0   0   0      0   0      0.0625 0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             arabinan            0    0    0    0   0   0      0   0      0.611  0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             mannan              0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             galactan            0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             lignin              0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             glucose             0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             glucose-oligomer    0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             cellobiose          0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             xylose              0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             xylose-oligomer     0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             arabinose           0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             mannose             0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             galactose           0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             acetic-acid         0    0    0    0   0   0.078  0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0.00039  0.99994  1        1        1        0         0        0         0        0        0    0
             furfural            0    0    0    0   0   0.61   0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0.00595  0.99981  0.99645  0.99645  0.99953  0.99953   0.99953  0.99953   0.99645  0.99645  0    0
             soluble-lignin      0    0    0    0   0   0      0   1      1      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             CO2                 0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    1        1        0        0        0        0         0        0         0        0        0    0
             C2H5OH              0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0.01412  0.00983  0.00998  0.00998  0.005    0.005     0.005    0.005     0.00998  0.00998  0    0
             glycerol            0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0.9618   0        0         0        0         0        0        0    0
             succinic-acid       0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             lactic-acid         0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             HMF                 0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0.00588  1        0        0        0        0         0        0         0        0        0    0
             Zmobilis            0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             xylitol             0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             gypsum              0    0    0    0   0   1      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             inert               0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             crude-oil           0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             C6-frac             0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             H2                  0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             IBP62               0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             gasoline            0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             remv-hydrofin       0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             diesel              0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             benzene             0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             pentane             0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             isopentane          0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             butane              0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             isobutane           0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             propane             0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             dry-gas             0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             sulfur              0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             boiler-fuel         0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0
             losser              0    0    0    0   0   0      0   0      0      0    0    0   0   0    0    0    0    0    0    0    0    0        1        0        0        0        0         0        0         0        0        0    0 ;

Table       alpha(i,cascas) ratio of chemical consume in the reaction
                             1    2    3    4    5    6    7    8    9      10    11   12   13   14    15    16    17    18    19    20    21   22    23    24   25    26        27       28       29      30   31    32   33
             EMIMBF4         0    0    0    0    0    0    0    0    0      0      0    0    0    0    0     0     0     0     0     0     0     0    0     0     0   1.89E-06   0        0        0       0    0     0    0
             BMIMCl          0    0    0    0    0    0    0    0    0      0      0    0    0    0    0     0     0     0     0     0     0     0    0     0     0    0        1.89E-06  0        0       0    0     0    0
             EMIMEtSO4       0    0    0    0    0    0    0    0    0      0      0    0    0    0    0     0     0     0     0     0     0     0    0     0     0    0         0       1.89E-06  0       0    0     0    0
             EMIMDMP         0    0    0    0    0    0    0    0    0      0      0    0    0    0    0     0     0     0     0     0     0     0    0     0     0    0         0        0      1.89E-06  0    0     0    0
             EG              0    0    0    0    0    0    0    0    0      0      0    0    0    0    0     0     0     0     0     0     0     0    0   0.011   0    0         0        0        0       0    0     0    0
             H2O             0    0    1    1    1    1    1    1    1      1      1    1    1    1    1     1     1     0     0     0     0     0    0     0     0    0         0        0        0       0    0     0    0
             sulfuric-acid   0    0    0    0    0    1    0    0    0      1      1    0    0    0    0     0     0     0     0     0     0     0    0     0     0    0         0        0        0       0    0     0    0
             lime            0    0    0    0    0    1    0    0    0.146  0      0    0    0    0    0     0     0     0     0     0     0     0    0     0     0    0         0        0        0       0    0     0    0
             NH3             0    0    0    0    0.02 0    0    0    0      0      0    0    0    0    0     0     0     0     0     0     0     0    0     0     0    0         0        0        0       0    0     0    0
             NH4OH           0    0    0    0    0    0    0    0.02 0      0      0    0    0    0    0     0     0     0     0     0     0     0    0     0     0    0         0        0        0       0    0     0    0
             air             0    0    0    0    0    1    0    0    1      0      0    0    0    0    0     0     0     0     0     0     0     0    0     0     0    0         0        0        0       0    0     0    0
             citric-acid     0    0    0    0    1    0    1    1    1      0      0    0    0    0    0     0     0     0     0     0     0     0    0     0     0    0         0        0        0       0    0     0    0
             NREL-enzyme     0    0    0    0    0    0    0    0    0      0      0    1    0    0    0     0     0     0     0     0     0     0    0     0     0    0         0        0        0       0    0     0    0
             spezyme-enzyme  0    0    0    0    0    0    0    0    0      0      0    0    1    1    1     1     1     0     0     0     0     0    0     0     0    0         0        0        0       0    0     0    0
             CSL             0    0    0    0    0    0    0    0    0      0      0    0    0    0    0     0     0     0     1     0     1     0    0     0     0    0         0        0        0       0    0     0    0
             DAP             0    0    0    0    0    0    0    0    0      0      0    0    0    0    0     0     0     0     1     0     1     0    0     0     0    0         0        0        0       0    0     0    0
             glycerol        0    0    0    0    0    0    0    0    0      0      0    0    0    0    0     0     0     0     0     0     0     0    0     0   0.011  0         0        0        0       0    0     0    0
             C6-frac         0    1    0    0    0    0    0    0    0      0      0    0    0    0    0     0     0     0     0     0     0     0    0     0     0    0         0        0        0       0    0     0    0
             H2              0    1    0    0    0    0    0    0    0      0      0    0    0    0    0     0     0     0     0     0     0     0    0     0     0    0         0        0        0       0    0     0    0;

Table       mu(i,cascas) ratio of chemical added
                             1    2    3    4     5       6       7     8      9      10    11     12     13     14      15     16     17    18    19    20    21   22    23    24   25   26   27   28   29   30   31    32   33
             EMIMBF4         0    0    0    0     0       0       0     0      0      0      0      0      0      0      0      0      0     0     0     0     0     0    0     0     0  4.646  0    0    0    0    0    0    0
             BMIMCl          0    0    0    0     0       0       0     0      0      0      0      0      0      0      0      0      0     0     0     0     0     0    0     0     0    0   4.1   0    0    0    0    0    0
             EMIMEtSO4       0    0    0    0     0       0       0     0      0      0      0      0      0      0      0      0      0     0     0     0     0     0    0     0     0    0    0  5.549  0    0    0    0    0
             EMIMDMP         0    0    0    0     0       0       0     0      0      0      0      0      0      0      0      0      0     0     0     0     0     0    0     0     0    0    0    0  5.427  0    0    0    0
             EG              0    0    0    0     0       0       0     0      0      0      0      0      0      0      0      0      0     0     0     0     0     0    0   1.752   0    0    0    0    0    0    0    0    0
             H2O             0    0   0.6  0.54  1.402   2.7    5.46  1.409  1.581    0      0    0.015   0.015  0.015  0.015  0.015  0.015  0     0     0     0     0    0     0     0    0    0    0    0    0    0    0    0
             sulfuric-acid   0    0    0    0     0     0.026     0     0      0    0.004    0.5    0      0      0      0      0      0     0     0     0     0     0    0     0     0    0    0    0    0    0    0    0    0
             lime            0    0    0    0     0       1       0     0     0.052   0      0      0      0      0      0      0      0     0     0     0     0     0    0     0     0    0    0    0    0    0    0    0    0
             NH3             0    0    0    0    0.65     0       0     0      0      0      0      0      0      0      0      0      0     0     0     0     0     0    0     0     0    0    0    0    0    0    0    0    0
             NH4OH           0    0    0    0     0       0       0   2.068    0      0      0      0      0      0      0      0      0     0     0     0     0     0    0     0     0    0    0    0    0    0    0    0    0
             air             0    0    0    0     0     0.039     0     0      0      0      0      0      0      0      0      0      0     0     0     0     0     0    0     0     0    0    0    0    0    0    0    0    0
             citric-acid     0    0    0    0     0       0       0     0      0      0      0      0      0      0      0      0      0     0     0     0     0     0    0     0     0    0    0    0    0    0    0    0    0
             NREL-enzyme     0    0    0    0     0       0       0     0      0      0      0    0.001    0      0      0      0      0     0     0     0     0     0    0     0     0    0    0    0    0    0    0    0    0
             spezyme-enzyme  0    0    0    0     0       0       0     0      0      0      0      0     0.001  0.001  0.001  0.001  0.001  0     0     0     0     0    0     0     0    0    0    0    0    0    0    0    0
             CSL             0    0    0    0     0       0       0     0      0      0      0      0      0      0      0      0      0     0   0.005   0   0.0025  0    0     0     0    0    0    0    0    0    0    0    0
             DAP             0    0    0    0     0       0       0     0      0      0      0      0      0      0      0      0      0     0   0.0006  0   0.0003  0    0     0     0    0    0    0    0    0    0    0    0
             glycerol        0    0    0    0     0       0       0     0      0      0      0      0      0      0      0      0      0     0     0     0     0     0    0     0   2.597  0    0    0    0    0    0    0    0
             C6-frac         0  0.022  0    0     0       0       0     0      0      0      0      0      0      0      0      0      0     0     0     0     0     0    0     0     0    0    0    0    0    0    0    0    0
             H2              0  0.004  0    0     0       0       0     0      0      0      0      0      0      0      0      0      0     0     0     0     0     0    0     0     0    0    0    0    0    0    0    0    0  ;


Scalar      P1 dollar price of feedstock per kg /0.03/;


Parameter   P2(i) dollar price of chemical per kg  / EMIMBF4         985
                                                     BMIMCl          259
                                                     EMIMEtSO4       245
                                                     EMIMDMP         3678
                                                     EG              0.42
                                                     H2O             0.0002
                                                     sulfuric-acid   0.03
                                                     lime            0.08
                                                     NH3             0.93
                                                     NH4OH           1.00
                                                     CSL             0.18
                                                     DAP             0.12
                                                     glycerol        0.65  / ;

*  EMIMBF4 = 1-Ethyl-3-methylimidazolium tetrafluoroborate produced by BASF, =98% (H-NMR)
*  BMIMCl = 1-Butyl-3-methylimidazolium chloride produced by BASF, =95%
*  EMIMEtSO4 = 1-Ethyl-3-methylimidazolium ethyl sulfate produced by BASF, =95%
*  EMIMDMP = 1-Ethyl-3-methylimidazolium dimethyl phosphate =98.0% (HPLC/T)

Table       P3(i,cascas) dollar price of ethanol per kg
                            32       33
            C2H5OH          0.83      1
            succinic-acid   2.5       2.5
            propane         1.4       1.4;
parameter       P4 (cascas)  dollar fixed price for intervals /
                                                        1        0
                                                        2       100000
                                                        3       135801
                                                        4       135801
                                                        5       304382
                                                        6       300094
                                                        7       77139
                                                        8       323087
                                                        9       272381
                                                       10        18984
                                                       11       177069
                                                       12       550667
                                                       13       550667
                                                       14       550667
                                                       15       550667
                                                       16       550667
                                                       17       550667
                                                       18         0
                                                       19       1072006
                                                       20         0
                                                       21       1978248
                                                       22       24484
                                                       23       49278
                                                       24       38868
                                                       25       38868
                                                       26       38868
                                                       27       38868
                                                       28       38868
                                                       29       38868
                                                       30       42946
                                                       31       50000
                                                       32        0
                                                       33        0 /;

*Parameters  W1 optimization weight ethanol production /1/

*            W2 optimization weight waste production/0/

*            W3 optimization weight sales of ethanol  /0/

*            W4 optimization weight costs for raw materials /0/

*            W5 optimization weight costs /0/;

Table       gamma(i,cascas,rr) stoichiometric coefficient of products in reaction
                                                 1        2        3        4       5       6      7       8       9     10      11       12       13       14      15      16     17     18     19      20      21     22      23       24       25       26      27      28     29      30      31     32     33     34      35
            H2O.(5*9)                           -1       -1       -0.5     -1      -1       2      0       0      -1      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0
            H2O.(10*17)                          0        0        0        0       0       0      0       0       0      0       0      -0.5      -1       -1       0      -1     -1     -1      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0
            H2O.(19,21)                          0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       2.4    -2      0       0        0        0        2      -1.667  -1      0       0       0      0      0      0       0

            sulfuric-acid.(5*9)                  0        0        0        0       0       0      0       0       0     -1       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0

            lime.(5*9)                           0        0        0        0       0       0      0       0       0     -1       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0

            glucan.(5*9)                        -1       -1       -1        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0
            glucan.(10*17)                       0        0        0        0       0       0      0       0       0      0      -1       -1       -1        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0

            xylan.(5*9)                          0        0        0       -1      -1      -1      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0
            xylan.(10*17)                        0        0        0        0       0       0      0       0       0      0       0        0        0        0      -1      -1      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0

            acetate.(5*9)                        0        0        0        0       0       0     -1       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0

            arabinan.(5*9)                       0        0        0        0       0       0      0       0      -1      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0

            mannan.(10*17)                       0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0     -1      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0

            galactan.(10*17)                     0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0     -1      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0

            lignin.(5*9)                         0        0        0        0       0       0      0      -1       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0

            glucose.(5*9)                        1        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0
            glucose.(10*17)                      0        0        0        0       0       0      0       0       0      0       0        0        1        2       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0
            glucose.(19,21)                      0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0     -1      -1      -1     -1      -1       -1        0        0       0       0      0       0       0      0      0      0       0

            glucose-oligomer.(5*9)               0        1        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0
            glucose-oligomer.(10*17)             0        0        0        0       0       0      0       0       0      0       1        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0

            cellobiose.(5*9)                     0        0        0.5      0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0
            cellobiose.(10*17)                   0        0        0        0       0       0      0       0       0      0       0        0.5      0       -1       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0

            xylose.(5*9)                         0        0        0        1       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0
            xylose.(10*17)                       0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       1      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0
            xylose.(19,21)                       0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0       -1       -1      -1      -1     -1      -1      -1      0      0      0       0

            xylose-oligomer.(5*9)                0        0        0        0       1       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0
            xylose-oligomer.(10*17)              0        0        0        0       0       0      0       0       0      0       0        0        0        0       1       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0

            arabinose.(5*9)                      0        0        0        0       0       0      0       0       1      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0
            arabinose.(21)                       0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0     -1       0

            mannose.(10*17)                      0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      1      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0
            mannose.(21)                         0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0     -1      0      0       0

            galactose.(10*17)                    0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      1      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0
            galactose.(21)                       0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0     -1      0       0

            acetic-acid.(5*9)                    0        0        0        0       0       0      1       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0
            acetic-acid.(19,21)                  0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       3        0        0        0       0       0      0       2.5     0      0      0      0       0

            furfural.(5*9)                       0        0        0        0       0       1      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0

            soluble-lignin.(5*9)                 0        0        0        0       0       0      0       1       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0

            gypsum.(5*9)                         0        0        0        0       0       0      0       0       0      1       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0       0

            O2.(19)                              0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0.3     1      1       0        0        0        0.25    0.833   9.5    2.5     0       0      0      0      0       0
            O2.(21)                              0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0.3     1      1       0        0        0        0.25    0.833   0.5    2.5     0       0      0      0      0       0

            CO2.(19)                             0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      2       0       0     -2       0        0        1.667    0       0       0      -1.667  0       0      0      0      0       0
            CO2.(21)                             0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      2       0       0     -2       0        0        1.667    0       0       0      -1.667  0       0      2      2      1.667   0

            C2H5OH.(19)                          0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      2       0       0      0       0        0        1.667    0       0       0       0      0       0      0      0      0       0
            C2H5OH.(21)                          0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      2       0       0      0       0        0        1.667    0       0       0       0      0       0      2      2      1.667   0

            glycerol.(19,21)                     0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       2      0       0        0        0        0       1.667   0       0      0       0      0      0      0       0

            succinic-acid.(19,21)                0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      2       0        0        0        0       0       0       1.667  0       0      0      0      0       0

            lactic-acid.(19,21)                  0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        2        0        0       0       0       0      0       1.667  0      0      0       0

            xylitol.(19,21)                      0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       1       0      0       0      0      0      0       0

            crude-oil.(2)                        0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0       0      0       0      0      0      0      -1

            C6-frac.(2)                          0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0       0      0       0      0      0      0    -0.022

            H2.(2)                               0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0       0      0       0      0      0      0    -0.004

            IBP62.(2)                            0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0       0      0       0      0      0      0     0.023

            gasoline.(2)                         0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0       0      0       0      0      0      0     0.020

            remv-hydrofin.(2)                    0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0       0      0       0      0      0      0     0.007

            diesel.(2)                           0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0       0      0       0      0      0      0     0.266

            benzene.(2)                          0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0       0      0       0      0      0      0     0.008

            pentane.(2)                          0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0       0      0       0      0      0      0     0.017

            isopentane.(2)                       0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0       0      0       0      0      0      0     0.020

            butane.(2)                           0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0       0      0       0      0      0      0     0.020

            isobutane.(2)                        0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0       0      0       0      0      0      0     0.022

            propane.(2)                          0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0       0      0       0      0      0      0     0.025

            dry-gas.(2)                          0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0       0      0       0      0      0      0     0.011

            sulfur.(2)                           0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0       0      0       0      0      0      0     0.003

            boiler-fuel.(2)                      0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0       0      0       0      0      0      0     0.558

            losser.(2)                           0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0       0      0       0      0      0      0     0.028

Table       theta(react,cascas,rr) fraction conversion of the reactant
                                                 1        2        3        4       5       6      7       8       9     10      11       12       13       14      15      16     17     18     19      20      21     22      23       24       25       26      27      28     29      30      31     32     33     34     35
            sulfuric-acid.(6)                    0        0        0        0       0       0      0       0       0      1       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0

            glucan.(6)                           0.07     0.007    0.007    0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0
            glucan.(7)                           0.003    0.053    0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0
            glucan.(9)                           0.005    0.011    0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0
            glucan.(10)                          0        0        0        0       0       0      0       0       0      0       0        0        0.5      0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0
            glucan.(11)                          0        0        0        0       0       0      0       0       0      0       0        0        0.9      0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0
            glucan.(12)                          0        0        0        0       0       0      0       0       0      0       0.04     0.012    0.90     0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0
            glucan.(13)                          0        0        0        0       0       0      0       0       0      0       0        0        0.96     0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0
            glucan.(14)                          0        0        0        0       0       0      0       0       0      0       0        0        0.86     0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0
            glucan.(15)                          0        0        0        0       0       0      0       0       0      0       0        0        0.9      0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0
            glucan.(16)                          0        0        0        0       0       0      0       0       0      0       0        0        0.9      0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0
            glucan.(17)                          0        0        0        0       0       0      0       0       0      0       0        0        0.93     0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0

            xylan.(6)                            0        0        0        0.9     0.025   0.05   0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0
            xylan.(7)                            0        0        0        0.024   0.553   0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0
            xylan.(8)                            0        0        0        0       0.471   0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0
            xylan.(9)                            0        0        0        0.008   0.236   0      0       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0
            xylan.(13)                           0        0        0        0       0       0      0       0       0      0       0        0        0        0       0.14    0.776  0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0
            xylan.(14)                           0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0.44   0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0
            xylan.(15)                           0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0.56   0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0
            xylan.(16)                           0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0.85   0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0
            xylan.(17)                           0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0.7    0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0

            acetate.(6)                          0        0        0        0       0       0      1       0       0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0

            arabinan.(6)                         0        0        0        0       0       0      0       0       0.9    0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0

            mannan.(10)                          0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0.89   0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0

            galactan.(10)                        0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0.82   0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0

            lignin.(6)                           0        0        0        0       0       0      0       0.05    0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0
            lignin.(8)                           0        0        0        0       0       0      0       0.704   0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0
            lignin.(9)                           0        0        0        0       0       0      0       0.669   0      0       0        0        0        0       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0

            cellobiose.(12)                      0        0        0        0       0       0      0       0       0      0       0        0        0        1       0       0      0      0      0       0       0      0       0        0        0        0       0       0      0       0       0      0      0      0      0

            glucose.(19)                         0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0.900   0.04    0.004  0.006   0.015    0.002    0        0       0       0      0       0       0      0      0      0      0
            glucose.(21)                         0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0.95    0.02    0.004  0.006   0.015    0.002    0        0       0       0      0       0       0      0      0      0      0

            xylose.(19)                          0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0      0       0       0        0        0.80     0.04    0.003   0.046  0.009   0.014   0.002  0      0      0      0
            xylose.(21)                          0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0      0       0       0        0        0.85     0.019   0.003   0.046  0.009   0.014   0.002  0      0      0      0

            arabinose.(21)                       0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0      0       0       0        0        0        0       0       0      0       0       0      0      0      0.85   0

            mannose.(21)                         0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0      0       0       0        0        0        0       0       0      0       0       0      0.85   0      0      0

            galactose.(21)                       0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0      0       0       0        0        0        0       0       0      0       0       0      0      0.85   0      0

            crude-oil.(2)                        0        0        0        0       0       0      0       0       0      0       0        0        0        0       0       0      0      0      0       0      0       0       0        0        0        0       0       0      0       0       0      0      0      0      1;


Binary variable
y(cas)         1 if the selected process cas is selected or 0 otherwise;


*Define the optimization variables
VARIABLES
F(i,cas,cascas)        Inflow of component i to process cascas coming from cas
ff(i,cas)          Mass flow after the mixing point
ffbar(i,cas)       Mass flow after the reaction
ffdbar(i,cas)      Mass flow outside
R(i,cascas)          Chemical use in interval cascas
ethanolprod      Production of ethanol
waste            Amount of waste produced
sales            Sales of ethanol
cost             Operating cost
chemused(i)      All of  of chemical used
Z                Objective function
fixcost          cost of process
*Bact
;


positive variable F, ff, ffbar, ffdbar, waste, sidestream,fixcost;

*Boundary
Y.FX('1')=1;
Y.FX('2')=1;
Y.FX('18')=1;
Y.FX('19')=1;
Y.FX('20')=1;
Y.FX('21')=1;
Y.FX('22')=1;
Y.FX('23')=1;
Y.FX('33')=1;

*Y.FX('4')=1;
*Y.FX('9')=1;
*Y.FX('17')=1;
*Y.FX('27')=1;


EQUATIONS
                 E1
                 E2
                 E3
                 E4
                 E5a(i,cas)
                 E5b(i,cas)
                 E6(i)
                 E7(i,cas,cascas)
                 E8(i,cas)
                 E9(i,cascas)
                 E10
                 E11
                 E12(cascas)
                 E13(i,cascas)
                 E14(i)
                 E15(i)
                 E16(i,cascas)
                 E17(i,cascas)
*E18
*E19
E20a
E20b
E20c
E20d
*E21(i)
*E22
E21
*E23
*E24

OBJ1
OBJ2
OBJ3
OBJ4
*OBJ5

*Contraintes
*C1
*C2
*C3
*C4

;

* open limit constraints
E1..                              y('3') + y('4') =l= 1;
*C1..                               y('4') =e= 1;

E2..                              y('5')+y('6')+y('7')+y('8') + y('9') =l= 1;
*C2..                               y('9') =e= 1;

E3..                              y('10')+y('11')+y('12')+y('13')+Y('14')+Y('15')+y('16')+y('17') =l= 1;
*C3..                               y('17') =e= 1;

E4..                              y('24')+y('25')+y('26')+y('27')+ y('28')+y('29')+y('30')+y('31') =e= 1;
*C4..                               y('27') =e= 1;

* big-M notation
E5a(i,cascas)..                        ffdbar(i,cascas) =l= y(cascas)*M ;
E5b(i,cascas)..                        R(i,cascas) =l= y(cascas)*M ;

* feed enter from interval cas to interval cascas
E6(i)..                           ffdbar(i,'1') =e= PHI(i) ;

* Carry-over constraint
E7(i,cas,cascas)..                      F(i,cas,cascas) =l= ffdbar(i,cas)*SS(cas,cascas)*epsilon(i,cas,cascas) ;

* empty output constraint
E8(i,cas)$(ord(cas) lt 32 and ord(cas) NE 2)..           ffdbar(i,cas) =e= sum(cascas,F(i,cas,cascas)) ;

* Mixing
* chemical mixing constraint
E9(i,cascas)$(ord(i)ne 9)..                     R(i,cascas) =e= mu(i,cascas)* sum((ii,cas), F(ii,cas,cascas)) ;

E10..                                       R('lime','6') =e= (R('sulfuric-acid','6')/MW('sulfuric-acid'))*MW('lime') ;

E11..                                       R('lime','9') =e= mu('lime','9')* sum((ii,cas), F(ii,cas,'9')) ;

E12(cascas)$(ord(cascas) = 10 and ord(cascas) = 11)..   R('sulfuric-acid',cascas) =e= mu('sulfuric-acid',cascas)* F('H2O','6',cascas) ;

* chemical mixing equation
E13(i,cascas)$(ord(cascas) NE 20) ..        ff(i,cascas) =e= sum(cas,F(i,cas,cascas)) + alpha(i,cascas) * R(i,cascas) ;

E14(i)..                            ff(i,'20') =e= sum(cas$(ord(cas)>9 and ord(cas)<19), F(i,cas,'20'));

* chemical reaction
* crude oil distillation in term of reaction equation
E15(i)..                            ffbar(i,'2') =e= ff(i,'2')+ (sum((rr,react),gamma(i,'2',rr)*theta(react,'2',rr)*ff(react,'2')));

* biomass's reaction
E16(i,cascas)$(ord(cascas) NE 2)..          ffbar(i,cascas) =e= ff(i,cascas)+(sum((rr,react),gamma(i,cascas,rr)*theta(react,cascas,rr)*(ff(react,cascas)/MW(react))))*MW(i);


*waste equation
E17(i,cascas)$(ord(cascas)>1)..             ffdbar(i,cascas) =e= ffbar(i,cascas)*(1 - SW(i,cascas)) ;

*Ethanol constrain
* 81% constraint for interval 32

*E18 ..                              ffdbar('C2H5OH','32') =g= 0.81 * sum(i,ffdbar(i,'32')) ;

* 99.9% constraint for interval 33
*E19..                               ffdbar('C2H5OH','33') =g= 0.999 * sum(i,ffdbar(i,'33')) ;


* Objective function
E20a..                              ethanolprod =e= ffdbar('C2H5OH','33');
E20b..                              waste =e= sum(cascas, ffbar('H2O',cascas)*SW('H2O',cascas));
E20c..                              sales =e= sum( (i,cas),P3(i,cas)*ffdbar(i,cas));
*E20d..                              cost =e= (sum(i,PHI(i)*P1) + sum((i,cascas),P2(i)*R(i,cascas)*alpha(i,cascas)) + 0.05*ffdbar('C2H5OH','33')*ffdbar('C2H5OH','33') + 0.02*ffbar('gypsum','6')) ;
E20d..                              cost =e= (sum(i,PHI(i)*P1) + sum((i,cascas),P2(i)*R(i,cascas)*alpha(i,cascas)) + 0.05*ffdbar('C2H5OH','21') + 0.02*ffbar('gypsum','6')) ;

E21..                               fixcost =e= sum(cascas,y(cascas)*P4(cascas));
*E21(i) ..                           chemused(i) =e= sum(cascas, R(i,cascas)*alpha(i,cascas)) ;

*E22..                               waste =e= sum((i,cascas),ffbar(i,cascas)*SW(i,cascas))+ sum(i,sidestream(i)) ;

*E23..                              Bact =e= -fixcost+9.818*(((65737.5*0.87*ethanolprod)-(65737.5*cost)-(fixcost/20))*(1-0.33)+(fixcost/20));
*E24..                              Bact =g= 0;

OBJ1..                               z('ethanol') =e=  ethanolprod  ;
OBJ2..                                 z('fonct')=e=cost;
OBJ3..                           z('invest')=e=fixcost;
OBJ4..                             z('dechet')=e=waste;
*OBJ5..                             z('Bact')=e=Bact;

Model example / all /;

$STitle eps-constraint method

Set k1(k) the first element of k, km1(k) all but the first elements of k;
k1(k)$(ord(k)=1) = yes; km1(k)=yes; km1(k1) = no;
Set kk(k)     active objective function in constraint allobj
Parameter
   rhs(k)     right hand side of the constrained obj functions in eps-constraint
   maxobj(k)  maximum value from the payoff table
   minobj(k)  minimum value from the payoff table
Variables
   a_objval   auxiliary variable for the objective function
   obj        auxiliary variable during the construction of the payoff table
Positive Variables
   sl(k)      slack or surplus variables for the eps-constraints
Equations
   con_obj(k) constrained objective functions
   augm_obj   augmented objective function to avoid weakly efficient solutions
   allobj     all the objective functions in one expression;

con_obj(km1)..   z(km1) - dir(km1)*sl(km1) =e= rhs(km1);

* We optimize the first objective function and put the others as constraints
* the second term is for avoiding weakly efficient points
augm_obj..
  sum(k1,dir(k1)*z(k1))+1e-15*sum(km1,sl(km1)/(maxobj(km1)-minobj(km1))) =e= a_objval;

allobj..  sum(kk, dir(kk)*z(kk)) =e= obj;

Model mod_payoff    / example, allobj / ;
Model mod_epsmethod / example, con_obj, augm_obj / ;
option optcr=0.00001;
option limrow=0, limcol=0, solprint=off, solvelink=2;

Parameter
  payoff(k,k)  payoff tables entries;
Alias(k,kp);

* Generate payoff table applying lexicographic optimization
loop(kp,
  kk(kp)=yes;
  repeat
    solve mod_payoff using mip maximizing obj;
    payoff(kp,kk) = z.l(kk);
    z.fx(kk) = z.l(kk); // freeze the value of the last objective optimized
    kk(k++1) = kk(k);   // cycle through the objective functions
  until kk(kp); kk(kp) = no;
* release the fixed values of the objective functions for the new iteration
  z.up(k) = inf; z.lo(k) =-inf;
);
if (mod_payoff.modelstat<>1, abort 'no optimal solution for mod_payoff');

display payoff;
minobj(k)=smin(kp,payoff(kp,k));
maxobj(k)=smax(kp,payoff(kp,k));

$set fname p.%gams.scrext%
File fx solution points from eps-method / "%gams.scrdir%%fname%" /;

$if not set gridpoints $set gridpoints 40

Set g grid points /g0*g%gridpoints%/
    grid(k,g) grid
Parameter
    gridrhs(k,g) rhs of eps-constraint at grid point
    maxg(k) maximum point in grid for objective
    posg(k) grid position of objective
    firstOffMax, lastZero some counters
    numk(k) ordinal value of k starting with 1
    numg(g) ordinal value of g starting with 0;
lastZero=1; loop(km1, numk(km1)=lastZero; lastZero=lastZero+1); numg(g) = ord(g)-1;

grid(km1,g) = yes; // Here we could define different grid intervals for different objectives
maxg(km1) = smax(grid(km1,g), numg(g));
gridrhs(grid(km1,g))$(%min%=dir(km1)) = maxobj(km1) - numg(g)/maxg(km1)*(maxobj(km1)- minobj(km1));
gridrhs(grid(km1,g))$(%max%=dir(km1)) = minobj(km1) + numg(g)/maxg(km1)*(maxobj(km1)- minobj(km1));
display gridrhs;

* Walk the grid points and take shortcuts if the model becomes infeasible
posg(km1) = 0;
repeat
  rhs(km1) = sum(grid(km1,g)$(numg(g)=posg(km1)), gridrhs(km1,g));
  solve mod_epsmethod maximizing a_objval using mip;
  if (mod_epsmethod.modelstat<>1,  // not optimal is in this case infeasible
    lastZero = 0; loop(km1$(posg(km1)>0 and lastZero=0), lastZero=numk(km1));
    posg(km1)$(numk(km1)<=lastZero) = maxg(km1); // skip all solves for more demanding values of rhs(km1)
  else
    loop(k, put fx z.l(k):12:2); put /);

* Proceed forward in the grid
  firstOffMax = 0;
  loop(km1$(posg(km1)<maxg(km1) and firstOffMax=0), posg(km1)=posg(km1)+1; firstOffMax=numk(km1));
  posg(km1)$(numk(km1)<firstOffMax) = 0;
until sum(km1$(posg(km1)=maxg(km1)),1)=card(km1) and firstOffMax=0;
putclose fx; // close the point file

* Get unique solutions from the point file using some Posix Tools (awk, sort, uniq) that come with GAMS
$set awkscript awk.%gams.scrext%
file fa / "%gams.scrdir%%awkscript%" /; put fa 'BEGIN { printf("Table solutions(*,*)\n$ondelim\nsol';
loop(k, put ',' k.tl:0); putclose '\n"); }' / '{ print NR,$0 }' / 'END { print ";" }';
execute 'cd "%gams.scrdir%" && sort %fname% | uniq | awk -f %awkscript% > g.%gams.scrext% && gams g.%gams.scrext% o=gx.%gams.scrext% lo=0 gdx=soleps && mv -f soleps.gdx ..';

Set s Solutions /1*70/; Parameter solutions(s,k) Unique solutions;
execute_load 'soleps', solutions; display solutions;

$exit
* The display should produce a table with 18 unique solutions:



